@@ -1,7 +1,7 @@
 import typing
 
 from .base import Base
-from .routes import ACCOUNT, CUSTOM_DOMAINS, SERVER, MATCHES
+from .routes import ACCOUNT, CUSTOM_DOMAINS, SERVER
 
 from .http import AwaitingHttp, BlockingHttp
 
@@ -11,16 +11,15 @@ from .server.awaiting import ServerAwaiting
 from .match.awaiting import AwaitingMatch
 from .match.blocking import BlockingMatch
 
-from .settings import ServerSettings, MatchSettings
+from .settings import ServerSettings
 
 from .models.account import AccountModel
 from .models.server import ServerModel
-from .models.match import MatchModel
 
 from httpx import AsyncClient, Client
 
 
-__version__ = "0.1.2"
+__version__ = "0.1.4"
 __url__ = "https://dathost.readthedocs.io/en/latest/"
 __description__ = "Asynchronous / Synchronous dathost API wrapper."
 __author__ = "WardPearce"
@@ -58,31 +57,6 @@ class Awaiting(Base, AwaitingHttp):
         self.__client_closed = True
         await self._client.aclose()
 
-    async def create_match(self, match_settings: MatchSettings,
-                           ) -> typing.Tuple[MatchModel, AwaitingMatch]:
-        """Creates a match.
-
-        Parameters
-        ----------
-        match_settings : MatchSettings
-            Holds details on the match.
-
-        Returns
-        -------
-        MatchModel
-            Holds match details.
-        AwaitingMatch
-            Used to interact with a match.
-        """
-
-        data = await self._post(
-            MATCHES.create,
-            data=match_settings.playload,
-            read_json=True
-        )
-
-        return MatchModel(data), self.match(data["id"])
-
     def match(self, match_id: str) -> AwaitingMatch:
         """Used to interact with a match.
 
@@ -121,7 +95,7 @@ class Awaiting(Base, AwaitingHttp):
         data = await self._post(
             url=SERVER.create,
             read_json=True,
-            data=settings.playload,
+            data=settings.payload,
         )
 
         return ServerModel(data), self.server(data["id"])
@@ -212,31 +186,6 @@ class Blocking(Base, BlockingHttp):
             timeout=self._timeout
         )
 
-    def create_match(self, match_settings: MatchSettings,
-                     ) -> typing.Tuple[MatchModel, BlockingMatch]:
-        """Creates a match.
-
-        Parameters
-        ----------
-        match_settings : MatchSettings
-            Holds details on the match.
-
-        Returns
-        -------
-        MatchModel
-            Holds match details.
-        BlockingMatch
-            Used to interact with a match.
-        """
-
-        data = self._post(
-            MATCHES.create,
-            data=match_settings.playload,
-            read_json=True
-        )
-
-        return MatchModel(data), self.match(data["id"])
-
     def match(self, match_id: str) -> BlockingMatch:
         """Used to interact with a match.
 
@@ -275,7 +224,7 @@ class Blocking(Base, BlockingHttp):
         data = self._post(
             url=SERVER.create,
             read_json=True,
-            data=settings.playload,
+            data=settings.payload,
         )
 
         return ServerModel(data), self.server(data["id"])
